.. _spkg_database_jones_numfield:

database_jones_numfield: Table of number fields
=========================================================

Description
-----------

This is a table of number fields with bounded ramification and degree
at most 6.

License
-------

GPLv2+


Upstream Contact
----------------

sage-devel@googlegroups.com

Special Update/Build Instructions
---------------------------------

Created by taking the original old-style spkg and removing crud from it.

Type
----

optional


Dependencies
------------


Version Information
-------------------

package-version.txt::

    4


Equivalent System Packages
--------------------------


See https://repology.org/project/sage-data-jones-numfield/versions

However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.

